@@ -1,5 +1,5 @@
 
-### Copyright 2000-2004 Deepayan Sarkar <deepayan@stat.wisc.edu>,
+### Copyright (C) 2000-2005 Deepayan Sarkar <Deepayan.Sarkar@R-project.org>,
 ###
 ### This file is part of the lattice library for R.  It is made
 ### available under the terms of the GNU General Public License,
@@ -31,9 +31,9 @@ assign("last.object",     NULL,   env = .LatticeEnv)
 
 
 
-.onLoad <- function(lib, pkg) 
+.onLoad <- function(libname, pkgname) 
 {
-    library.dynam(pkg, pkg, lib )
+    library.dynam("lattice", pkgname, libname)
     lattice.options(.defaultLatticeOptions())
     lattice.setStatus(.defaultLatticeStatus())
 }
